from typing import Dict, Final, Optional, List

from edge.webserver.sysconf.dgmod.rn.rn_main import MainConfBuilder
from edge.webserver.sysconf.dgmod.rn.rn_setupstore import SetupStoreConfBuilder
from edge.webserver.sysconf.dgmod.rn.uiconf import IUiConfProvider


class _UiConfProvider(IUiConfProvider):
    def __init__(self, uimod_id: str, uiconf: Dict) -> None:
        self._uimod_id: Final[str] = uimod_id
        self._uiconf: Final[Dict] = uiconf

    def setup_builders(self, main_builder: MainConfBuilder, ss_builder: SetupStoreConfBuilder) -> None:
        pub_jnode: Dict = self._uiconf['rw']
        pri_jnode: Dict = self._uiconf['ro']
        live_jnode: Dict = pub_jnode['live']
        vs_jnode: Dict = live_jnode['videostream']
        v_jnode: Dict = live_jnode['renderer']['vehicle']

        main_builder.setup_roadway__enabled(v_jnode['video-lane'] != 'never')

        main_builder.setup_service_stats(f'zabbix/or{int(main_builder.uimod_id) % 10}')
        main_builder.setup_image_footer(vs_jnode['frame-w'], live_jnode['footer'])
        main_builder.setup_image_anno__conf(v_jnode)

        trafficlight_jnode: Optional[List] = pri_jnode.get('trafficlight')
        if trafficlight_jnode is not None:
            main_builder.setup_image_tl_anno__conf(trafficlight_jnode)

        ss_builder.setup_active(pub_jnode['enabled'])


HttpStreamingUiConfProvider = _UiConfProvider


class RtspStreamingUiConfProvider(_UiConfProvider):
    def __init__(self, uimod_id: str, uiconf: Dict) -> None:
        super().__init__(uimod_id, uiconf)

    def setup_builders(self, main_builder: MainConfBuilder, ss_builder: SetupStoreConfBuilder) -> None:
        super().setup_builders(main_builder, ss_builder)

        main_builder.setup_event_blobs('or{0}-or{0}-store'.format(main_builder.uimod_id), 'RGBA')
        main_builder.setup_event_args([
            'or{0}-rs{0}-scene'.format(main_builder.uimod_id)
        ])
